@@ -24,15 +24,14 @@ print.summary.betaclust <- function(x, digits = getOption("digits"), ...)
 
 
   tab <- data.frame("log-likelihood" = x$loglik,  "Information-criterion"=x$information_criterion,"IC-value" = x$ic_output,
-                    "CpG-sites" = x$C, "Patients" = x$N, "Samples" = x$R,
+                    "CpG-sites" = x$C, "Patients" = x$N, "Sample types" = x$R,
                     row.names = "", check.names = FALSE)
   print(tab)
   #
   cat("\nClustering table:")
-  #print(table(x$classification))
   print(x$classification)
 
-  cat("\nProportion of CpG sites in each cluster: \n")
+  cat("\nEstimated mixing proportions: \n")
   cat(x$prop_data)
   #
   invisible(x)
